ProcessMode

Enum ProcessMode 

pub enum ProcessMode {
    Realtime,
    Buffered,
    Offline,
}
The plugin’s current processing mode. Exposed through BufferConfig::process_mode. The host will reinitialize the plugin whenever this changes.

Variants



Realtime

The plugin is processing audio in real time at a fixed rate.



Buffered

The plugin is processing audio at a real time-like pace, but at irregular intervals. The host may do this to process audio ahead of time to loosen realtime constraints and to reduce the chance of xruns happening. This is only used by VST3.



Offline

The plugin is rendering audio offline, potentially faster than realtime (‘freewheeling’). The host will continuously call the process function back to back until all audio has been processed.