BufferConfig

Struct BufferConfig 

pub struct BufferConfig {
    pub sample_rate: f32,
    pub min_buffer_size: Option<u32>,
    pub max_buffer_size: u32,
    pub process_mode: ProcessMode,
}
Configuration for (the host’s) audio buffers.

Fields

sample_rate: f32

The current sample rate.

min_buffer_size: Option<u32>

The minimum buffer size the host will use. This may not be set.

max_buffer_size: u32

The maximum buffer size the host will use. The plugin should be able to accept variable sized buffers up to this size, or between the minimum and the maximum buffer size if both are set.

process_mode: ProcessMode

The current processing mode. The host will reinitialize the plugin any time this changes.