PortNames

Struct PortNames 

pub struct PortNames {
    pub layout: Option<&'static str>,
    pub main_input: Option<&'static str>,
    pub main_output: Option<&'static str>,
    pub aux_inputs: &'static [&'static str],
    pub aux_outputs: &'static [&'static str],
}
Contains names for the ports defined in an AudioIOLayout. Setting these is optional, but it makes working with multi-output plugins much more convenient.

All of these names should start with a capital letter to be consistent with automatically generated names.

Fields

layout: Option<&'static str>

The name for the audio IO layout as a whole. Useful when a plugin has multiple distinct layouts. Will be generated if not set.

main_input: Option<&'static str>

The name for the main input port. Will be generated if not set.

main_output: Option<&'static str>

The name for the main output port. Will be generated if not set.

aux_inputs: &'static [&'static str]

Names for auxiliary (sidechain) input ports. Will be generated if not set or if this slice does not contain enough names.

aux_outputs: &'static [&'static str]

Names for auxiliary output ports. Will be generated if not set or if this slice does not contain enough names.

Implementations

Source

impl PortNames

pub const fn const_default() -> Self

PortNames::default(), but as a const function. Used when initializing Plugin::AUDIO_IO_LAYOUTS. (https://github.com/rust-lang/rust/issues/67792)