Block

Struct Block 

pub struct Block<'slice, 'sample: 'slice> { /* private fields */ }
A block yielded by BlocksIter. Can be iterated over once or multiple times, and also supports direct access to the block’s samples if needed.

Implementations

Source

impl<'slice, 'sample> Block<'slice, 'sample>

pub fn samples(&self) -> usize

Get the number of samples per channel in the block.

pub fn channels(&self) -> usize

Returns the number of channels in this buffer.

pub fn iter_mut(&mut self) -> BlockChannelsIter<'slice, 'sample>

A resetting iterator. This lets you iterate over the same block multiple times. Otherwise you don’t need to use this function as Block already implements Iterator. You can also use the direct accessor functions on this block instead.

pub fn iter_samples(&mut self) -> SamplesIter<'slice, 'sample>

Iterate over this block on a per-sample per-channel basis. This is identical to Buffer::iter_samples() but for a smaller block instead of the entire buffer

pub fn get(&self, channel_index: usize) -> Option<&[f32]>

Access a channel by index. Useful when you would otherwise iterate over this Block multiple times.

pub unsafe fn get_unchecked(&self, channel_index: usize) -> &[f32]

The same as get(), but without any bounds checking.

Safety

channel_index must be in the range 0..Self::len().

pub fn get_mut(&mut self, channel_index: usize) -> Option<&mut [f32]>

Access a mutable channel by index. Useful when you would otherwise iterate over this Block multiple times.

pub unsafe fn get_unchecked_mut(&mut self, channel_index: usize) -> &mut [f32]

The same as get_mut(), but without any bounds checking.

Safety

channel_index must be in the range 0..Self::len().

pub fn to_channel_simd<const LANES: usize>( &self, sample_index: usize, ) -> Option<Simd<f32, LANES>>

Get a SIMD vector containing the channel data for a specific sample in this block. If `LANES

channels.len()then this will be padded with zeroes. IfLANES < channels.len()` then this won’t contain all values.

Returns a None value if sample_index is out of bounds.

pub unsafe fn to_channel_simd_unchecked<const LANES: usize>( &self, sample_index: usize, ) -> Simd<f32, LANES>

Get a SIMD vector containing the channel data for a specific sample in this block. Will always read exactly LANES channels, and does not perform bounds checks on sample_index.

Safety

Undefined behavior if LANES > block.len() or if sample_index > block.len().

pub fn from_channel_simd<const LANES: usize>( &mut self, sample_index: usize, vector: Simd<f32, LANES>, ) -> bool

Write data from a SIMD vector to this sample’s channel data for a specific sample in this block. This takes the padding added by to_channel_simd() into account.

Returns false if sample_index is out of bounds.

pub unsafe fn from_channel_simd_unchecked<const LANES: usize>( &mut self, sample_index: usize, vector: Simd<f32, LANES>, )

Write data from a SIMD vector to this sample’s channel data for a specific sample in this block.. This assumes LANES matches exactly with the number of channels in the buffer, and does not perform bounds checks on sample_index.

Safety

Undefined behavior if LANES > block.len() or if sample_index > block.len().