ChannelSamples

Struct ChannelSamples 

pub struct ChannelSamples<'slice, 'sample: 'slice> { /* private fields */ }
Can construct iterators over actual iterator over the channel data for a sample, yielded by SamplesIter. Can be turned into an iterator, or ChannelSamples::iter_mut() can be used to iterate over the channel data multiple times, or more efficiently you can use ChannelSamples::get_unchecked_mut() to do the same thing.

Implementations

Source

impl<'slice, 'sample> ChannelSamples<'slice, 'sample>

pub fn len(&self) -> usize

Get the number of channels.

pub fn iter_mut(&mut self) -> ChannelSamplesIter<'slice, 'sample>

A resetting iterator. This lets you iterate over the same channels multiple times. Otherwise you don’t need to use this function as ChannelSamples already implements IntoIterator.

pub fn get_mut(&mut self, channel_index: usize) -> Option<&mut f32>

Access a sample by index. Useful when you would otherwise iterate over this ‘Channels’ iterator multiple times.

pub unsafe fn get_unchecked_mut(&mut self, channel_index: usize) -> &mut f32

The same as get_mut(), but without any bounds checking.

Safety

channel_index must be in the range 0..Self::len().

pub fn to_simd<const LANES: usize>(&self) -> Simd<f32, LANES>

Get a SIMD vector containing the channel data for this buffer. If LANES > channels.len() then this will be padded with zeroes. If LANES < channels.len() then this won’t contain all values.

pub unsafe fn to_simd_unchecked<const LANES: usize>(&self) -> Simd<f32, LANES>

Get a SIMD vector containing the channel data for this buffer. Will always read exactly LANES channels.

Safety

Undefined behavior if LANES > channels.len().

pub fn from_simd<const LANES: usize>(&mut self, vector: Simd<f32, LANES>)

Write data from a SIMD vector to this sample’s channel data. This takes the padding added by to_simd() into account.

pub unsafe fn from_simd_unchecked<const LANES: usize>( &mut self, vector: Simd<f32, LANES>, )

Write data from a SIMD vector to this sample’s channel data. This assumes LANES matches exactly with the number of channels in the buffer.

Safety

Undefined behavior if LANES > channels.len().