Module context

Module context 

Different contexts the plugin can use to make callbacks to the host in different…contexts.

Modules

gui
A context passed to a plugin’s editor.
init
A context passed during plugin initialization.
process
A context passed during the process function.
remote_controls
A context for defining plugin-specific remote pages for CLAP plugins.

Enums

PluginApi
The currently active plugin API. This may be useful to display in an about screen in the plugin’s GUI for debugging purposes.