Module process

Module process 

A context passed during the process function.

Structs

Transport
Information about the plugin’s transport. Depending on the plugin API and the host not all fields may be available.

Traits

ProcessContext
Contains both context data and callbacks the plugin can use during processing. Most notably this is how a plugin sends and receives note events, gets transport information, and accesses sidechain inputs and auxiliary outputs. This is passed to the plugin during as part of Plugin::process().