pub enum SendEventError {
HostBufferFull,
NoOutputBuffer,
InvalidEvent {
midi_output_config: MidiConfig,
},
}Expand description
An error occurred while sending an event with ProcessContext::try_send_event().
Variants
HostBufferFull
The host’s output event buffer is full.
NoOutputBuffer
The host does not have an output event buffer.
InvalidEvent
Invalid event type for the plugin’s Plugin::MIDI_OUTPUT configuration.
Fields

midi_output_config: MidiConfigTrait Implementations
Sourceimpl Clone for SendEventError
impl Clone for SendEventError
Sourcefn clone(&self) -> SendEventError
fn clone(&self) -> SendEventError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SendEventError
Sourceimpl Debug for SendEventError
impl Debug for SendEventError
Sourceimpl Display for SendEventError
impl Display for SendEventError
impl Eq for SendEventError
Sourceimpl Error for SendEventError
impl Error for SendEventError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for SendEventError
impl PartialEq for SendEventError
impl StructuralPartialEq for SendEventError