Module remote_controls

Module remote_controls 

A context for defining plugin-specific remote pages for CLAP plugins.

Traits

RemoteControlsContext
A context for defining plugin-specific remote pages for CLAP plugins.
RemoteControlsPage
A page containing references to up to eight parameters. If the number of slots used exceeds eight, then the page is split automatically. In that case the split page will have indices appended to it. For example, the Lengty Params Page defining 16 parameters will become Lengty Params Page 1 and Lengthy Params Page 2.
RemoteControlsSection
A section or group of parameter pages. Empty sections will not be visible when using the plugin.