RemoteControlsContext

Trait RemoteControlsContext 

pub trait RemoteControlsContext {
    type Section: RemoteControlsSection;

    // Required method
    fn add_section(
        &mut self,
        name: impl Into<String>,
        f: impl FnOnce(&mut Self::Section),
    );
}
A context for defining plugin-specific remote pages for CLAP plugins.

These pages can contain references to up to eight parameters, but if the plugin defines more parameters for a page then the pages are automatically split.

Required Associated Types

Required Methods

fn add_section( &mut self, name: impl Into<String>, f: impl FnOnce(&mut Self::Section), )

Define a section containing one or more remote control pages. This can be used to group remote control pages together. For instance, because an oscillator has so many parameters that it needs to span multiple pages, or to group the parameters for both filters into a single section.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors