Module dpi

Module dpi 

Structs

LogicalInsets
The logical distance between the edges of two rectangles.
LogicalPosition
A position represented in logical pixels.
LogicalSize
A size represented in logical pixels.
LogicalUnit
A logical pixel unit.
NativeSize
A size represented in the platform’s native pixels.
PhysicalInsets
The physical distance between the edges of two rectangles.
PhysicalPosition
A position represented in physical pixels.
PhysicalSize
A size represented in physical pixels.
PhysicalUnit
A physical pixel unit.

Enums

Insets
Insets that are either physical or logical.
PixelUnit
A pixel unit that’s either physical or logical.
Position
A position that’s either physical or logical.
Size
A size that’s either physical or logical.

Traits

Pixel

Functions

validate_scale_factor
Checks that the scale factor is a normal positive f64.