pub enum ParentWindowHandle {
XlibWindow(c_ulong),
XcbWindow(NonZeroU32),
AppKitNsView(NonNull<c_void>),
Win32Hwnd(NonZeroIsize),
}Expand description
A raw window handle for platform and GUI framework agnostic editors. This implements
HasWindowHandle so it can be used directly with GUI libraries that use the same
raw_window_handle version. If the library links against a different version of
raw_window_handle, then you’ll need to wrap around this type and implement the trait yourself.
Variants
XlibWindow(c_ulong)
The ID of the host’s parent window. Used with X11.
XcbWindow(NonZeroU32)
The ID of the host’s parent window. Used with X11.
AppKitNsView(NonNull<c_void>)
A handle to the host’s parent window. Used only on macOS.
Win32Hwnd(NonZeroIsize)
A handle to the host’s parent window. Used only on Windows.