pub struct SpawnedEditor<E: EditorHandle> {
pub handle: E,
pub window: E::Window,
}Fields
handle: EA handle to the instance of an open Editor.
When this handle is dropped, the editor instance is also dropped.
window: E::WindowThe owned window handle
This will usually be baseview::Window. This is type-erased to avoid needing nice-plug-core
to depend on baseview until it has a stable version.
When this is dropped, the window should be automatically closed.