macro_rules! nice_debug_assert {
($cond:expr $(,)?) => { ... };
($cond:expr, $format:expr $(, $($args:tt)*)?) => { ... };
}Expand description
A debug_assert!() analogue that prints the error with line number information instead of
panicking. During tests this is upgraded to a regular panicking debug_assert!().
TODO: Detect if we’re running under a debugger, and trigger a break if we are