nice_log

Macro nice_log 

macro_rules! nice_log {
    ($($args:tt)*) => { ... };
}
Write something to the logger. This defaults to STDERR unless the user is running Windows and a debugger has been attached, in which case OutputDebugString() will be used instead.

The logger’s behavior can be controlled by setting the NICE_LOG environment variable to:

  • stderr, in which case the log output always gets written to STDERR.
  • windbg (only on Windows), in which case the output always gets logged using OutputDebugString().
  • A file path, in which case the output gets appended to the end of that file which will be created if necessary.