macro_rules! nice_trace {
($($args:tt)*) => { ... };
}Expand description
The same as nice_log!(), but with source and thread information. Like the
nice_debug_assert*!() macros, this is only shown when compiling in debug mode.
macro_rules! nice_trace {
($($args:tt)*) => { ... };
}The same as nice_log!(), but with source and thread information. Like the
nice_debug_assert*!() macros, this is only shown when compiling in debug mode.