pub enum Key {
Wildcard,
Number(u8),
}Expand description
The key number of the note. This is also sometimes referred to as the “pitch”.
Same as MIDI1 Key Number (60 == Middle C)
Variants
Wildcard
The note can belong to any key.
Number(u8)
The note’s key number, in 0..127.
Same as MIDI1 Key Number (60 == Middle C)
Implementations
Sourceimpl Key
impl Key
Sourcepub const fn number(&self) -> Option<u8>
pub const fn number(&self) -> Option<u8>
Return the key number if it exists, or return None if it is a wildcard (the note
can belong to any key).
Sourcepub const fn number_or_middle_c(&self) -> u8
pub const fn number_or_middle_c(&self) -> u8
Return the key number if it exists, or return Middle C (60) if it is a wildcard.
Sourcepub const fn is_wildcard(&self) -> bool
pub const fn is_wildcard(&self) -> bool
Returns true if this is a wildcard (the note can belong to any channel).