MidiConfig

Enum MidiConfig 

pub enum MidiConfig {
    None,
    Basic,
    MidiCCs,
}
Determines which note events a plugin can send and receive.

Variants



None

The plugin will not have a note input or output port and will thus not receive any not events.



Basic

The plugin receives note on/off/choke events, pressure, and potentially a couple standardized expression types depending on the plugin standard and host. If the plugin sets up configuration for polyphonic modulation and assigns polyphonic modulation IDs to some of its parameters, then it will also receive polyphonic modulation events. This level is also needed to be able to send SysEx events.



MidiCCs

The plugin receives full MIDI CCs as well as pitch bend information. For VST3 plugins this involves adding 130*16 parameters to bind to the the 128 MIDI CCs, pitch bend, and channel pressure.