MidiResult

Enum MidiResult 

pub enum MidiResult<S: SysExMessage> {
    Basic([u8; 3]),
    SysEx(S::Buffer, usize),
}
The result of converting a NoteEvent<S> to MIDI. This is a bit weirder than it would have to be because it’s not possible to use associated constants in type definitions.

Variants



Basic([u8; 3])

A basic three byte MIDI event.



SysEx(S::Buffer, usize)

A SysEx event. The message was written to the S::Buffer and may include padding at the end. The usize value indicates the message’s actual length, including headers and end of SysEx byte.