pub enum VoiceID {
Wildcard,
ID(i32),
}Expand description
The identifier given to a specific voice. This is also known as the “note ID”.
Variants
Implementations
Sourceimpl VoiceID
impl VoiceID
Sourcepub const fn id(&self) -> Option<i32>
pub const fn id(&self) -> Option<i32>
Return the ID of the voice if it exists, or return None if it is a wildcard (the note
can belong to any voice).
Sourcepub const fn is_wildcard(&self) -> bool
pub const fn is_wildcard(&self) -> bool
Returns true if this is a wildcard (the note can belong to any voice).
Sourcepub fn id_or_fallback(&self, key: Key, channel: Channel) -> i32
pub fn id_or_fallback(&self, key: Key, channel: Channel) -> i32
Compute a voice ID if the host didn’t provide one. Polyphonic modulation will not work in this case, but playing notes will.