Module params

Module params 

nice-plug can handle floating point, integer, boolean, and enum parameters. Parameters are managed by creating a struct deriving the Params trait containing fields for those parameter types, and then returning a reference to that object from your Plugin::params() method. See the Params trait for more information.

Re-exports

pub use enums::EnumParam;

Modules

enums
Enum parameters. enum is a keyword, so enums it is.
internals
Implementation details for the parameter management.
persist
Traits and helpers for persistent fields. See the Params trait for more information.
range
Different ranges for numeric parameters.
smoothing
Utilities to handle smoothing parameter changes over time.

Structs

BoolParam
A simple boolean parameter.
FloatParam
A floating point parameter that’s stored unnormalized. The range is used for the normalization process.
IntParam
A discrete integer parameter that’s stored unnormalized. The range is used for the normalization process.
ParamFlags
Flags for controlling a parameter’s behavior.

Traits

InternalParamMut
Contains the setters for parameters. Only to be used by nice-plug’s internal libraries. These are exposed as unsafe methods to avoid confusion.
Param
Describes a single parameter of any type. Most parameter implementations also have a field called value that and a field called smoothed. The former stores the latest unsmoothed value, and the latter can be used to access the smoother. These two fields should be used in DSP code to either get the parameter’s current (smoothed) value. In UI code the getters from this trait should be used instead.
Params
Describes a struct containing parameters and other persistent fields.

Derive Macros

Params
Derive the Params trait for your plugin’s parameters struct. See the Plugin trait.