EnumParamInner

Struct EnumParamInner 

pub struct EnumParamInner { /* private fields */ }
The type-erased internals for EnumParam so that the wrapper can interact with it. Acts like an IntParam but with different conversions from strings to values.

Implementations

Source

impl EnumParamInner

pub fn len(&self) -> usize

Get the number of variants for this enum.

pub fn unmodulated_plain_id(&self) -> Option<&'static str>

Get the stable ID for the parameter’s current value according to unmodulated_plain_value(). Returns None if this enum parameter doesn’t have any stable IDs.

pub fn set_from_id(&self, id: &str) -> bool

Set the parameter based on a serialized stable string identifier. Return whether the ID was known and the parameter was set.