Module persist

Module persist 

Traits and helpers for persistent fields. See the Params trait for more information.

Modules

serialize_atomic_cell
Can be used with the #[serde(with = "nice_plug::params::internals::serialize_atomic_cell")] attribute to serialize AtomicCell<T>s.

Traits

PersistentField
Handles the functionality needed for persisting a non-parameter fields in a plugin’s state. These types can be used with Params#[persist = "..."] attributes.

Functions

deserialize_field
Re-export for use in the Params proc-macro. Deserialize an instance of type T from a string of JSON text.
serialize_field
Re-export for use in the Params proc-macro. Serialize the given data structure as a String of JSON.