Module smoothing

Module smoothing 

Utilities to handle smoothing parameter changes over time.

Structs

AtomicF32
A floating point type which can be safely shared between threads.
Smoother
A smoother, providing a smoothed value for each sample.
SmootherIter
An iterator that continuously produces smoothed values. Can be used as an alternative to the block-based smoothing API. Since the iterator itself is infinite, you can use Smoother::is_smoothing() and Smoother::steps_left() to get information on the current smoothing status.

Enums

SmoothingStyle
Controls if and how parameters gets smoothed.

Traits

Smoothable
A type that can be smoothed. This exists just to avoid duplicate explicit implementations for the smoothers.