IntParam

Struct IntParam 

pub struct IntParam {
    pub smoothed: Smoother<i32>,
    /* private fields */
}
A discrete integer parameter that’s stored unnormalized. The range is used for the normalization process.

Fields

smoothed: Smoother<i32>

An optional smoother that will automatically interpolate between the new automation values set by the host.

Implementations

Source

impl IntParam

pub fn new(name: impl Into<String>, default: i32, range: IntRange) -> Self

Build a new IntParam. Use the other associated functions to modify the behavior of the parameter.

pub fn value(&self) -> i32

The field’s current plain value, after monophonic modulation has been applied. Equivalent to calling param.plain_value().

pub fn range(&self) -> IntRange

The range of valid plain values for this parameter.

pub fn with_poly_modulation_id(self, id: u32) -> Self

Enable polyphonic modulation for this parameter. The ID is used to uniquely identify this parameter in NoteEvent::PolyModulation events, and must thus be unique between all polyphonically modulatable parameters. See the event’s documentation on how to use polyphonic modulation. Also consider configuring the ClapPlugin::CLAP_POLY_MODULATION_CONFIG constant when enabling this.

Important

After enabling polyphonic modulation, the plugin must start sending NoteEvent::VoiceTerminated events to the host when a voice has fully ended. This allows the host to reuse its modulation resources.

pub fn with_smoother(self, style: SmoothingStyle) -> Self

Set up a smoother that can gradually interpolate changes made to this parameter, preventing clicks and zipper noises.

pub fn with_callback(self, callback: Arc<dyn Fn(i32) + Send + Sync>) -> Self

Run a callback whenever this parameter’s value changes. The argument passed to this function is the parameter’s new value. This should not do anything expensive as it may be called multiple times in rapid succession, and it can be run from both the GUI and the audio thread.

pub fn with_unit(self, unit: &'static str) -> Self

Display a unit when rendering this parameter to a string. Appended after the value_to_string function if that is also set. nice-plug will not automatically add a space before the unit.

pub fn with_value_to_string( self, callback: Arc<dyn Fn(i32) -> String + Send + Sync>, ) -> Self

Use a custom conversion function to convert the plain, unnormalized value to a string.

pub fn with_string_to_value( self, callback: Arc<dyn Fn(&str) -> Option<i32> + Send + Sync>, ) -> Self

Use a custom conversion function to convert from a string to a plain, unnormalized value. If the string cannot be parsed, then this should return a None. If this happens while the parameter is being updated then the update will be canceled.

The input string may or may not contain the unit, so you will need to be able to handle that.

pub fn non_automatable(self) -> Self

Mark the parameter as non-automatable. This means that the parameter cannot be changed from an automation lane. The parameter can however still be manually changed by the user from either the plugin’s own GUI or from the host’s generic UI.

pub fn hide(self) -> Self

Hide the parameter in the host’s generic UI for this plugin. This also implies NON_AUTOMATABLE. Setting this does not prevent you from changing the parameter in the plugin’s editor GUI.

pub fn hide_in_generic_ui(self) -> Self

Don’t show this parameter when generating a generic UI for the plugin using one of nice-plug’s generic UI widgets.