Module plugin

Module plugin 

Traits and structs describing plugins and editors. This includes extension structs for features that are specific to one or more plugin-APIs.

Structs

PluginState
A plugin’s state so it can be restored at a later point. This object can be serialized and deserialized using serde.

Enums

ParamValue
A plain, unnormalized value for a parameter.
ProcessStatus
Indicates the current situation after the plugin has processed audio.

Traits

Plugin
The main plugin trait covering functionality common across most plugin formats. Most formats also have another trait with more specific data and functionality that needs to be implemented before the plugin can be exported to that format. The wrappers will use this to expose the plugin in a particular plugin format.

Type Aliases

TaskExecutor
A function that can execute a plugin’s BackgroundTasks. A plugin can dispatch these tasks from the initialize() function, the process() function, or the GUI, so they can be deferred for later to avoid blocking realtime contexts.