A context passed to a plugin’s editor.
Structs
- Async
Executor - An way to run background tasks from the plugin’s GUI, equivalent to the
ProcessContext::execute_background()andProcessContext::execute_gui()functions. This is passed directly toPlugin::editor()so the plugin can move it into its editor and use it later. - Param
Setter - A convenience helper for setting parameter values. Any changes made here will be broadcasted to
the host and reflected in the plugin’s
Paramsobject. These functions should only be called from the main thread.
Traits
- GuiContext
- Callbacks the plugin can make when the user interacts with its GUI such as updating parameter
values. This is passed to the plugin during
Editor::spawn(). All of these functions assume they’re being called from the main GUI thread.