A context for defining plugin-specific remote pages for CLAP plugins.
Traits
- Remote
Controls Context - A context for defining plugin-specific remote pages for CLAP plugins.
- Remote
Controls Page - A page containing references to up to eight parameters. If the number of slots used exceeds
eight, then the page is split automatically. In that case the split page will have indices
appended to it. For example, the
Lengty Params Pagedefining 16 parameters will becomeLengty Params Page 1andLengthy Params Page 2. - Remote
Controls Section - A section or group of parameter pages. Empty sections will not be visible when using the plugin.