pub trait RemoteControlsPage {
// Required methods
fn add_param(&mut self, param: &impl Param);
fn add_spacer(&mut self);
}Expand description
A page containing references to up to eight parameters. If the number of slots used exceeds
eight, then the page is split automatically. In that case the split page will have indices
appended to it. For example, the Lengty Params Page defining 16 parameters will become Lengty Params Page 1 and Lengthy Params Page 2.
Required Methods
fn add_param(&mut self, param: &impl Param)
fn add_spacer(&mut self)
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.