pub enum ParentWindowHandle {
X11Window(u32),
AppKitNsView(*mut c_void),
Win32Hwnd(*mut c_void),
}Expand description
A raw window handle for platform and GUI framework agnostic editors. This implements
HasRawWindowHandle so it can be used directly with GUI libraries that use the same
raw_window_handle version. If the library links against a different version of
raw_window_handle, then you’ll need to wrap around this type and implement the trait yourself.
Variants
X11Window(u32)
The ID of the host’s parent window. Used with X11.
AppKitNsView(*mut c_void)
A handle to the host’s parent window. Used only on macOS.
Win32Hwnd(*mut c_void)
A handle to the host’s parent window. Used only on Windows.