pub struct HostMethods {
pub callbacks: Box<dyn HostCallbacks>,
pub main_thread_caller: Box<dyn HostMainThreadCaller>,
}Expand description
Callbacks that baseview windows can use to interact with the host.
Fields
callbacks: Box<dyn HostCallbacks>A handler for baseview windows to interact with their host.
(This is a re-implementation of
baseview::host::HostCallbacks
to avoid directly depending on baseview until it is stabilized.)
main_thread_caller: Box<dyn HostMainThreadCaller>A special handler for the Window thread to wake up and call methods on the main thread.
(This is a re-implementation of
baseview::host::HostMainThreadCaller
to avoid directly depending on baseview until it is stabilized.)
Platform compatibility notes
This is only needed on X11, as Windows and macOS windows already run on the main thread.