macro_rules! nice_dbg {
() => { ... };
($val:expr $(,)?) => { ... };
($($val:expr),+ $(,)?) => { ... };
}Expand description
Analogues to the dbg!() macro, but respecting the NICE_LOG environment variable and with all
of the same logging features as the other nice_*!() macros. Like the nice_debug_assert*!()
macros, this is only shown when compiling in debug mode, but the macro will still return the
value in non-debug modes.