Constants and definitions surrounding MIDI support.
Modules
- control_
change - Constants to represent controller change types.
- sysex
- Traits for working with MIDI SysEx data.
Enums
- Midi
Config - Determines which note events a plugin can send and receive.
- Midi
Result - The result of converting a
NoteEvent<S>to MIDI. This is a bit weirder than it would have to be because it’s not possible to use associated constants in type definitions. - Note
Event - Event for (incoming) notes. The set of supported note events depends on the value of
[
Plugin::MIDI_INPUT. Also check out theutilmodule for convenient conversion functions.
Type Aliases
- Plugin
Note Event - A plugin-specific note event type.