Function serialize_field
Source pub fn serialize_field<T>(value: &T) -> Result<String, Error>
Re-export for use in the Params proc-macro.
Serialize the given data structure as a String of JSON.
Errors
Serialization can fail if T’s implementation of Serialize decides to
fail, or if T contains a map with non-string keys.